==> 0.0.4.tar.gz: lib/package/tree.dart <==
import 'package:flutter/material.dart';
import './tree_node.dart';

class MillTree extends StatefulWidget {
  MillTree({
    Key key,
    @required this.tree,
    this.defaultValue,
    this.onChange,
    this.alasLabel = 'label',
    this.alasValue = 'value',
  }) : super(key: key);
  final Map tree;
  final List defaultValue;
  final Function onChange;
  final String alasLabel;
  final String alasValue;

  @override
  _MillTree createState() => new _MillTree();
}

class _MillTree extends State<MillTree> {
  List _value;
  int maxStack = 1;
  Map<String, dynamic> _tree = {};
  @override
  void initState() {
    _value = widget.defaultValue;
    _tree = _initData(widget.tree);
    super.initState();
  }

  @override
  didUpdateWidget(oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.defaultValue != oldWidget.defaultValue) {
      _value = widget.defaultValue;
      _tree = _initData(widget.tree);
    }
  }

  _onChange(tree) {
    setState(() {
      _tree = tree;
    });
    if (widget.onChange != null) {
      widget.onChange(tree);
    }
  }

  _initData(data, {int state, int index = 0, bool disabled}) {
    int checked = _value.indexOf(data[widget.alasValue]) > -1
        ? 1
        : state != null
            ? state
            : 0;
    bool isDisabled = data['disabled'] != null
        ? data['disabled']
        : disabled != null
            ? disabled
            : false;
    Map<String, dynamic> result = {
      'checked': checked,
      '${widget.alasLabel}': data[widget.alasLabel],
      '${widget.alasValue}': data[widget.alasValue],
      'stack': index,
      'disabled': isDisabled,
    };
    if (data['children'] != null && data['children'].length > 0) {
      int newIndex = index + 1;
      result['children'] = data['children']
          .map((el) => _initData(el,
              disabled: isDisabled, state: checked, index: newIndex))
          .toList();
    } else {
      result['children'] = [];
    }
    maxStack = index;
    var selected = result['children'].where((val) => val['checked'] == 1);
    var im = result['children'].where((val) => val['checked'] == 2);
    if (selected.length > 0) {
      result['checked'] = selected.length == result['children'].length ? 1 : 2;
    } else if (im.length > 0) {
      result['checked'] = 2;
    }
    return result;
  }

  @override
  Widget build(BuildContext context) {
    return ListView(
      children: <Widget>[
        Container(
          padding: EdgeInsets.all(20),
          color: Color(0xffffffff),
          child: TreeNode(
              data: _tree,
              onChange: _onChange,
              alasLabel: widget.alasLabel,
              alasValue: widget.alasValue,
              showCheckeds: maxStack),
        )
      ],
    );
  }
}

==> 0.0.7.tar.gz: lib/package/tree.dart <==
import 'package:flutter/material.dart';
import './tree_node.dart';

class MillTree extends StatefulWidget {
  MillTree({
    Key key,
    @required this.tree,
    this.defaultValue,
    this.onChange,
    this.aliasLabel = 'label',
    this.aliasValue = 'value',
  }) : super(key: key);
  final Map tree;
  final List defaultValue;
  final Function onChange;
  final String aliasLabel;
  final String aliasValue;

  @override
  _MillTree createState() => new _MillTree();
}

class _MillTree extends State<MillTree> {
  List _value;
  int maxStack = 1;
  Map<String, dynamic> _tree = {};
  @override
  void initState() {
    _value = widget.defaultValue;
    _tree = _initData(widget.tree);
    super.initState();
  }

  @override
  didUpdateWidget(oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.defaultValue != oldWidget.defaultValue) {
      _value = widget.defaultValue;
      _tree = _initData(widget.tree);
    }
  }

  _onChange(tree) {
    setState(() {
      _tree = tree;
    });
    if (widget.onChange != null) {
      widget.onChange(tree);
    }
  }

  _initData(data, {int state, int index = 0, bool disabled}) {
    int checked = _value.indexOf(data[widget.aliasValue]) > -1
        ? 1
        : state != null
            ? state
            : 0;
    bool isDisabled = data['disabled'] != null
        ? data['disabled']
        : disabled != null
            ? disabled
            : false;
    Map<String, dynamic> result = {
      'checked': checked,
      '${widget.aliasLabel}': data[widget.aliasLabel],
      '${widget.aliasValue}': data[widget.aliasValue],
      'stack': index,
      'disabled': isDisabled,
    };
    if (data['children'] != null && data['children'].length > 0) {
      int newIndex = index + 1;
      result['children'] = data['children']
          .map((el) => _initData(el,
              disabled: isDisabled, state: checked, index: newIndex))
          .toList();
    } else {
      result['children'] = [];
    }
    maxStack = index;
    var selected = result['children'].where((val) => val['checked'] == 1);
    var im = result['children'].where((val) => val['checked'] == 2);
    if (selected.length > 0) {
      result['checked'] = selected.length == result['children'].length ? 1 : 2;
    } else if (im.length > 0) {
      result['checked'] = 2;
    }
    return result;
  }

  @override
  Widget build(BuildContext context) {
    return ListView(
      children: <Widget>[
        Container(
          padding: EdgeInsets.all(20),
          color: Color(0xffffffff),
          child: TreeNode(
              data: _tree,
              onChange: _onChange,
              aliasLabel: widget.aliasLabel,
              aliasValue: widget.aliasValue,
              showCheckeds: maxStack),
        )
      ],
    );
  }
}
